using System;
using Autofac;
using FitConnect;
using FitConnect.Interfaces;
using FitConnect.Interfaces.Subscriber;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace IntegrationTests.Subscriber;

public abstract class SubscriberTestBase {
    protected readonly Guid DestinationId = new Guid("aa3704d6-8bd7-4d40-a8af-501851f93934");
    private const string ClientId = "20175c2b-c4dd-4a01-99b1-3a08436881a1";
    private const string ClientSecret = "KV2qd7qc5n-xESB6dvfrTlMDx2BWHJd5hXJ6pKKnbEQ";
    private IContainer _container = null!;
    protected ILogger Logger = null!;
    protected ISubscriber Subscriber { get; set; } = null!;

    [OneTimeSetUp]
    public void OneTimeSetUp() {
        // One-time initialization code
        _container = Container.Create();
    }

    [SetUp]
    public void SetUp() {
        // Code here will be called before every test


        Logger = LoggerFactory.Create(b => {
                b.AddConsole();
                b.SetMinimumLevel(LogLevel.Warning);
            })
            .CreateLogger<FitConnect.Sender>();

        Subscriber = new FitConnect.Subscriber(
            FitConnectEnvironment.Test,
            ClientId,
            ClientSecret,
            _container.Resolve<IFitConnectSettings>().PrivateDecryptionKeys,
            _container.Resolve<IFitConnectSettings>().PrivateSigningKey,
            Logger);
    }


    [TearDown]
    public void TearsDown() {
        // Code here will be called after every test
    }

    [OneTimeTearDown]
    public void OneTimeTearDown() {
        // One-time cleanup code
    }
}
